@@ -242,31 +242,33 @@ class Artist(Node[ArtistInsert]):
         model_name = "Artist"
         client = client
         updatable_fields: T.Set[str] = {
-            "bio",
-            "media",
+            "admin_details",
             "band_configuration",
-            "created_at",
+            "bio",
+            "bookings",
             "category",
-            "slug",
+            "connect_account_id",
             "contact_information",
             "cover_image",
+            "created_at",
             "last_backend_updated",
-            "spotify_id",
-            "last_triggered_at",
-            "subgenres",
-            "name",
-            "venue_take_percentages",
-            "migration_version",
-            "published",
-            "admin_details",
-            "connect_account_id",
-            "social_media",
             "last_redis_refreshed",
-            "version",
+            "last_triggered_at",
             "last_updated",
+            "media",
+            "migration_version",
+            "name",
             "profile_image",
+            "published",
+            "sellers",
+            "slug",
+            "social_media",
+            "spotify_id",
+            "subgenres",
+            "venue_take_percentages",
+            "version",
         }
-        exclusive_fields: T.Set[str] = {"id", "slug", "beatgig_id"}
+        exclusive_fields: T.Set[str] = {"beatgig_id", "id", "slug"}
 
 
 class ArtistResolver(Resolver[Artist]):
@@ -392,12 +394,15 @@ class Booking(Node[BookingInsert]):
         model_name = "Booking"
         client = client
         updatable_fields: T.Set[str] = {
+            "account_exec",
+            "artist",
+            "buyer",
+            "created_at",
             "negotiation_steps",
             "performance_length_mins",
-            "created_at",
             "start_time",
         }
-        exclusive_fields: T.Set[str] = {"id", "beatgig_id"}
+        exclusive_fields: T.Set[str] = {"beatgig_id", "id"}
 
 
 class BookingResolver(Resolver[Booking]):
@@ -621,30 +626,35 @@ class User(Node[UserInsert]):
         model_name = "User"
         client = client
         updatable_fields: T.Set[str] = {
-            "approval",
-            "metadata",
-            "email",
-            "user_type",
-            "phone_number",
+            "account_exec_bookings",
             "admin_permissions",
-            "default_state_abbr",
-            "last_triggered_at",
-            "user_role",
-            "referred_by_id",
-            "name",
-            "slug",
-            "created_at",
             "admin_type",
-            "last_updated",
-            "profile_image",
+            "approval",
             "approved",
+            "artists",
+            "bookings",
+            "created_at",
+            "default_state_abbr",
+            "email",
+            "last_triggered_at",
+            "last_updated",
+            "metadata",
+            "name",
+            "phone_number",
+            "profile_image",
+            "referred_by_id",
+            "slug",
+            "user_role",
+            "user_type",
+            "venues",
+            "venues_assigned_to",
         }
         exclusive_fields: T.Set[str] = {
-            "firebase_id",
-            "phone_number",
-            "id",
-            "slug",
             "beatgig_id",
+            "firebase_id",
+            "id",
+            "phone_number",
+            "slug",
         }
 
 
@@ -771,7 +781,7 @@ class Movie(Node[MovieInsert]):
     class GraphORM:
         model_name = "Movie"
         client = client
-        updatable_fields: T.Set[str] = {"title", "year"}
+        updatable_fields: T.Set[str] = {"actors", "director", "title", "year"}
         exclusive_fields: T.Set[str] = {"id"}
 
 
@@ -914,13 +924,16 @@ class Person(Node[PersonInsert]):
         model_name = "Person"
         client = client
         updatable_fields: T.Set[str] = {
+            "best_friend",
+            "created_at",
             "first_name",
-            "tags",
             "full_name",
             "last_name",
-            "slug",
-            "created_at",
+            "my_followers",
             "ordered_tags",
+            "people_i_follow",
+            "slug",
+            "tags",
         }
         exclusive_fields: T.Set[str] = {"id", "slug"}
 
@@ -1142,28 +1155,32 @@ class Venue(Node[VenueInsert]):
         model_name = "Venue"
         client = client
         updatable_fields: T.Set[str] = {
+            "account_exec",
+            "bookings",
             "budget",
-            "created_at",
-            "logo",
-            "slug",
-            "place_id",
-            "location",
-            "phone_number",
-            "production_and_venue_specs",
-            "display_images",
-            "name",
             "capacity",
             "colors",
-            "images",
-            "genres_booked",
+            "created_at",
+            "created_by",
             "customer_id",
-            "website",
+            "display_images",
+            "genres_booked",
+            "images",
+            "last_updated",
+            "location",
+            "logo",
+            "name",
+            "num_stages",
+            "owners",
+            "phone_number",
+            "place_id",
+            "production_and_venue_specs",
+            "slug",
             "social_media",
             "venue_type",
-            "last_updated",
-            "num_stages",
+            "website",
         }
-        exclusive_fields: T.Set[str] = {"id", "slug", "beatgig_id"}
+        exclusive_fields: T.Set[str] = {"beatgig_id", "id", "slug"}
 
 
 class VenueResolver(Resolver[Venue]):
@@ -1268,13 +1285,13 @@ class Animal(Node[AnimalInsert]):
         model_name = "Animal"
         client = client
         updatable_fields: T.Set[str] = {
-            "description",
-            "animal_type",
-            "name",
-            "slug",
-            "created_at",
             "age",
+            "animal_type",
+            "created_at",
+            "description",
+            "name",
             "public_id",
+            "slug",
         }
         exclusive_fields: T.Set[str] = {"id", "public_id", "slug"}
 
