@@ -224,8 +224,8 @@ def build_node_and_resolver(object_type: ObjectType) -> str:
         )
     orm_config_str = build_orm_config(
         model_name=object_type.node_name,
-        updatable_fields=updatable_fields,
-        exclusive_fields=exclusive_fields,
+        updatable_fields={*updatable_fields, *updatable_links},
+        exclusive_fields={*exclusive_fields, *exclusive_links},
     )
 
     insert_model_name = f"{object_type.node_name}Insert"
