@@ -198,8 +198,6 @@ class Node(BaseModel, T.Generic[InsertType]):
         """Turn insert into a string with variables"""
         if not given_resolver:
             given_resolver = cls.GraphORM.resolver_type()
-        if batch and upsert_given_conflict_on:
-            raise NodeException("You cannot batch add with upsert fields.")
         if custom_on_conflict_str:
             if return_conflicting_model_on or upsert_given_conflict_on:
                 raise NodeException(
@@ -213,10 +211,6 @@ class Node(BaseModel, T.Generic[InsertType]):
         # if your intention is for them to update on upsert, then add ADD to the resolver
         s, variables = basemodel_to_str(insert, default_replace=True)
         insert_str = f"INSERT {cls._model_name} {s}"
-        if batch:
-            batch.add(line=insert_str, variables={**variables})
-            # should I screw up the types for this?
-            return None
         conflict_str = ""
         if custom_on_conflict_str:
             conflict_str = custom_on_conflict_str
@@ -232,9 +226,12 @@ class Node(BaseModel, T.Generic[InsertType]):
             conflict_str = f"UNLESS CONFLICT ON .{upsert_given_conflict_on} ELSE (UPDATE {cls._model_name} SET {update_s})"
         elif return_conflicting_model_on:
             conflict_str = f"UNLESS CONFLICT ON .{return_conflicting_model_on} ELSE (SELECT {cls._model_name})"
-        select_str = f"SELECT model {given_resolver.to_str()}"
         if conflict_str:
             insert_str += f" {conflict_str}"
+        if batch:
+            batch.add(line=insert_str, variables={**variables})
+            return None
+        select_str = f"SELECT model {given_resolver.to_str()}"
         add_s = f"WITH model := ({insert_str}) {select_str}"
         raw_d = await execute_query(
             client=given_client or cls.db_client,
